#!/bin/sh
##
##  Partition Logic
##  Copyright (C) 1998-2004 J. Andrew McLaughlin
## 
##  install.sh
##

# Installs the Partition Logic system on the requested device.  Suitable for
# use only with Partition Logic SOURCE distribution.  Note that the device
# must have permissions which allow direct writes by the invoking user. 

BUILDDIR=../build
BOOTSECTOR=${BUILDDIR}/system/boot/bootsect.fat12
OSLOADER=vloader
FSTAB=/etc/fstab
INSTFILES=../dist/system/install-files

echo ""
echo "Partition Logic installation script for UNIX"
echo ""

DEVICE=$1
if [ "$DEVICE" = "" ] ; then
    echo "No installation device specified."
    echo "Usage: $0 <installation device>"
    echo "Terminating."
    echo ""
    exit 1
elif [ ! -e $DEVICE ] ; then
    echo "Installation device does not exist."
    echo "Usage: $0 <installation device>"
    echo "Terminating."
    echo ""
    exit 1
fi
echo "Installing Partition Logic on $DEVICE"

# Make sure we have write permission on the device
if [ ! -w "$DEVICE" ] ; then
    echo ""
    echo "You do not have permission to write directly to the disk device"
    echo "file ($DEVICE) on this system.  (try 'chmod go+rw $DEVICE')."
    echo "Terminating."
    echo ""
    exit 1
fi

# Just to a quick check to see whether we think a build has been done
if [ ! -e "$BOOTSECTOR" ] ; then
    echo ""
    echo "$BOOTSECTOR is missing.  Have you done a make yet?"
    echo "Terminating."
    echo ""
    exit 1
fi

MNTARGS=
# If it is a regular device, format it
if [ -b "$DEVICE" ] ; then
    echo -n "Formatting...  "
    # Format the disk.  Stop if the command fails.
    /sbin/mkdosfs -F12 $DEVICE >& /dev/null
    if [ $? -ne 0 ] ; then
	echo ""
	echo Not able to format disk $DEVICE.  Terminating.
	echo ""
	exit 1
    else
	echo Done
    fi
else
    MNTARGS="-o loop,sync"
fi

# Install the boot sector
./copy-boot.sh $BOOTSECTOR $DEVICE
if [ $? -ne 0 ] ; then
    exit $?
fi

# Try to figure out where the disk gets mounted by reading the fstab
# file.  If this is not working on your system, you should override
# this manually (or fix the following command)
MOUNTDIR=`cat $FSTAB | grep $DEVICE | awk '{print $2}'`

if [ "$MOUNTDIR" != "" ] ; then
    mount $DEVICE
else
    MOUNTDIR=tmp_mnt
    mkdir -p $MOUNTDIR
    mount $MNTARGS $DEVICE $MOUNTDIR
fi

# Mount the filesystem
if [ $? -ne 0 ] ; then
    echo ""
    echo "Not able (or not permitted) to mount disk $DEVICE.  Terminating."
    echo ""
    exit 1
fi

# Copy files from the build directory
echo -n "Copying files...  "
for FILE in `cat $INSTFILES` ; do
    if [ -d "$BUILDDIR""$FILE" ] ; then
	mkdir -p "$MOUNTDIR""$FILE"
    elif [ -f "$BUILDDIR""$FILE" ] ; then
	cp "$BUILDDIR""$FILE" "$MOUNTDIR""$FILE"
    fi
done

sync
echo Done

# Uncomment to have the os loader print out hardware/boot information
# touch $MOUNTDIR/bootinfo
# Uncomment to disable graphics mode
# touch $MOUNTDIR/nograph

# Unmount the filesystem
umount $MOUNTDIR

if [ -d tmp_mnt ] ; then
    rmdir tmp_mnt
fi

exit 0
